@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# MinIO Python Library for Amazon S3 Compatible Cloud Storage, (C) 2015 MinIO, Inc.
+# MinIO Python Library for Amazon S3 Compatible Cloud Storage,
+# (C) 2015 MinIO, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,36 +14,36 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import unittest.mock as mock
 from datetime import timedelta
-
-import mock
-from nose.tools import raises
 from unittest import TestCase
 
 from minio import Minio
-from minio.error import InvalidArgumentError
 
 
 class PresignedGetObjectTest(TestCase):
-    @raises(TypeError)
     def test_object_is_string(self):
         client = Minio('localhost:9000')
-        client.presigned_get_object('hello', 1234)
+        self.assertRaises(
+            TypeError, client.presigned_get_object, 'hello', 1234)
 
-    @raises(ValueError)
     def test_object_is_not_empty_string(self):
         client = Minio('localhost:9000')
-        client.presigned_get_object('hello', ' \t \n ')
+        self.assertRaises(
+            ValueError, client.presigned_get_object, 'hello', ' \t \n ')
 
-    @raises(InvalidArgumentError)
     def test_expiry_limit(self):
         client = Minio('localhost:9000')
-        client.presigned_get_object('hello', 'key', expires=timedelta(days=8))
+        self.assertRaises(
+            ValueError,
+            client.presigned_get_object, 'hello', 'key',
+            expires=timedelta(days=8)
+        )
 
     def test_can_include_response_headers(self):
         client = Minio('localhost:9000', 'my_access_key', 'my_secret_key',
                        secure=True)
-        client._get_bucket_region = mock.Mock(return_value='us-east-1')
+        client._get_region = mock.Mock(return_value='us-east-1')
         r = client.presigned_get_object(
             'mybucket', 'myfile.pdf',
             response_headers={
