@@ -14,13 +14,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from nose.tools import raises
 from unittest import TestCase
 
 from minio import Minio
 
+
 class TraceTest(TestCase):
-    @raises(ValueError)
     def test_bucket_is_string(self):
         client = Minio('localhost:9000')
-        client.trace_on(None)
+        self.assertRaises(ValueError, client.trace_on, None)
